Point Style | Chart.js
Description: Open source HTML5 Charts for your website

# # Point Style

This sample show how to use the dataset point style in the legend instead of a rectangle to identify each dataset..

const config = { type: 'line', data: data, options: { plugins: { legend: { labels: { usePointStyle: true, }, } } } };

    const config = {
      type: 'line',
      data: data,
      options: {
        plugins: {
          legend: {
            labels: {
              usePointStyle: true,
            },
          }
        }
      }
    };

const DATA_COUNT = 7; const NUMBER_CFG = {count: DATA_COUNT, min: -100, max: 100}; const data = { labels: Utils.months({count: DATA_COUNT}), datasets: [ { label: 'Dataset 1', data: Utils.numbers(NUMBER_CFG), fill: false, borderColor: Utils.CHART_COLORS.red, backgroundColor: Utils.transparentize(Utils.CHART_COLORS.red, 0.5), borderWidth: 1, pointStyle: 'rectRot', pointRadius: 5, pointBorderColor: 'rgb(0, 0, 0)' }, ] };

    const DATA_COUNT = 7;
    const NUMBER_CFG = {count: DATA_COUNT, min: -100, max: 100};
    const data = {
      labels: Utils.months({count: DATA_COUNT}),
      datasets: [
        {
          label: 'Dataset 1',
          data: Utils.numbers(NUMBER_CFG),
          fill: false,
          borderColor: Utils.CHART_COLORS.red,
          backgroundColor: Utils.transparentize(Utils.CHART_COLORS.red, 0.5),
          borderWidth: 1,
          pointStyle: 'rectRot',
          pointRadius: 5,
          pointBorderColor: 'rgb(0, 0, 0)'
        },
      ]
    };

const actions = [ { name: 'Toggle Point Style', handler(chart) { chart.options.plugins.legend.labels.usePointStyle = !chart.options.plugins.legend.labels.usePointStyle; chart.update(); } }, ];

    const actions = [
      {
        name: 'Toggle Point Style',
        handler(chart) {
          chart.options.plugins.legend.labels.usePointStyle = !chart.options.plugins.legend.labels.usePointStyle;
          chart.update();
        }
      },
    ];

## # Docs

- Data structures (`labels`)
- Line
- Legend
  - Legend Label Configuration
    - `usePointStyle`
- Elements
  - Point Configuration
  - Point Styles